@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,11 +21,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 import weakref
 
 from message import Message
-from common import IntDict, Debug
+from common import IntDict, Debug, StrMixin
 from tile import Tile
 
 
-class AIDefault(object):
+class AIDefault:
 
     """all AI code should go in here"""
 
@@ -331,7 +331,7 @@ class AIDefault(object):
 #        return result
 
 
-class TileAI(object):
+class TileAI(StrMixin):
 
     """holds a few AI related tile properties"""
     # pylint: disable=too-many-instance-attributes
@@ -369,9 +369,6 @@ class TileAI(object):
         dang = ' dang:%d' % self.dangerous if self.dangerous else ''
         return '%s:=%.4f%s' % (self.tile, self.keep, dang)
 
-    def __repr__(self):
-        return 'TileAI(%s)' % str(self)
-
 
 class DiscardCandidates(list):
 
